==> richfaces-distribution-4.5.10.Final.zip: META-INF/resources/org.richfaces.staticResource/4.5.10.Final/Compressed/org.richfaces/fileupload.js <==
(function(D,I){I.ui=I.ui||{};
I.ui.FileUpload=function(O,M){this.id=O;
this.items=[];
this.submitedItems=[];
D.extend(this,M);
if(this.acceptedTypes){this.acceptedTypes=D.trim(this.acceptedTypes).toUpperCase().split(/\s*,\s*\.?/)
}if(this.maxFilesQuantity){this.maxFilesQuantity=parseInt(D.trim(this.maxFilesQuantity))
}this.element=D(this.attachToDom());
this.form=this.element.parents("form:first");
var N=this.element.children(".rf-fu-hdr:first");
var L=N.children(".rf-fu-btns-lft:first");
this.addButton=L.children(".rf-fu-btn-add:first");
this.uploadButton=this.addButton.next();
this.clearButton=L.next().children(".rf-fu-btn-clr:first");
this.inputContainer=this.addButton.find(".rf-fu-inp-cntr:first");
this.input=this.inputContainer.children("input");
this.list=N.next();
this.element.bind("dragenter",function(P){P.stopPropagation();
P.preventDefault()
});
this.element.bind("dragover",function(P){P.stopPropagation();
P.preventDefault()
});
this.element.bind("drop",D.proxy(this.__addItemsFromDrop,this));
this.hiddenContainer=this.list.next();
this.cleanInput=this.input.clone();
this.addProxy=D.proxy(this.__addItems,this);
this.input.change(this.addProxy);
this.addButton.mousedown(E).mouseup(H).mouseout(H);
this.uploadButton.click(D.proxy(this.__startUpload,this)).mousedown(E).mouseup(H).mouseout(H);
this.clearButton.click(D.proxy(this.__removeAllItems,this)).mousedown(E).mouseup(H).mouseout(H);
if(this.onfilesubmit){I.Event.bind(this.element,"onfilesubmit",new Function("event",this.onfilesubmit))
}if(this.ontyperejected){I.Event.bind(this.element,"ontyperejected",new Function("event",this.ontyperejected))
}if(this.onsizerejected){I.Event.bind(this.element,"onsizerejected",new Function("event",this.onsizerejected))
}if(this.onuploadcomplete){I.Event.bind(this.element,"onuploadcomplete",new Function("event",this.onuploadcomplete))
}if(this.onclear){I.Event.bind(this.element,"onclear",new Function("event",this.onclear))
}if(this.onfileselect){I.Event.bind(this.element,"onfileselect",new Function("event",this.onfileselect))
}};
var A="rf_fu_uid";
var J="rf_fu_uid_alt";
var K="C:\\fakepath\\";
var G='<div class="rf-fu-itm"><span class="rf-fu-itm-lft"><span class="rf-fu-itm-lbl"/><span class="rf-fu-itm-st" /><div class="progress progress-striped active"><div class="progress-bar" role="progressbar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100" style="width: 0%"><span></span></div></div></span><span class="rf-fu-itm-rgh"><a href="javascript:void(0)" class="rf-fu-itm-lnk"/></span></div>';
var F={NEW:"new",UPLOADING:"uploading",DONE:"done",SIZE_EXCEEDED:"sizeExceeded",STOPPED:"stopped",SERVER_ERROR_PROCESS:"serverErrorProc",SERVER_ERROR_UPLOAD:"serverErrorUp"};
var E=function(L){D(this).children(":first").css("background-position","3px 3px").css("padding","4px 4px 2px 22px")
};
var H=function(L){D(this).children(":first").css("background-position","2px 2px").css("padding","3px 5px 3px 21px")
};
I.BaseComponent.extend(I.ui.FileUpload);
function B(L){this.name="TypeRejectedException";
this.message="The type of file "+L+" is not accepted";
this.fileName=L
}D.extend(I.ui.FileUpload.prototype,(function(){return{name:"FileUpload",doneLabel:"Done",sizeExceededLabel:"File size is exceeded",stoppedLabel:"",serverErrorProcLabel:"Server error: error in processing",serverErrorUpLabel:"Server error: upload failed",clearLabel:"Clear",deleteLabel:"Delete",__addFiles:function(N){var M={acceptedFileNames:[],rejectedFileNames:[]};
if(N){for(var L=0;
L<N.length;
L++){this.__tryAddItem(M,N[L]);
if(this.maxFilesQuantity&&this.__getTotalItemCount()>=this.maxFilesQuantity){this.addButton.hide();
break
}}}else{var O=this.input.val();
this.__tryAddItem(M,O)
}if(M.rejectedFileNames.length>0){I.Event.fire(this.element,"ontyperejected",M.rejectedFileNames.join(","))
}if(this.immediateUpload){this.__startUpload()
}},__addItems:function(){this.__addFiles(this.input.prop("files"))
},__addItemsFromDrop:function(L){L.stopPropagation();
L.preventDefault();
if(this.maxFilesQuantity&&this.__getTotalItemCount()>=this.maxFilesQuantity){return 
}this.__addFiles(L.originalEvent.dataTransfer.files)
},__tryAddItem:function(M,L){if(this.maxFileSize&&L.size>this.maxFileSize){I.Event.fire(this.element,"onsizerejected",L);
return 
}try{if(this.__addItem(L)){M.acceptedFileNames.push(L.name)
}}catch(N){if(N instanceof B){M.rejectedFileNames.push(L.name)
}else{throw N
}}},__addItem:function(L){var N=L.name;
if(!navigator.platform.indexOf("Win")){N=N.match(/[^\\]*$/)[0]
}else{if(!N.indexOf(K)){N=N.substr(K.length)
}else{N=N.match(/[^\/]*$/)[0]
}}if(this.__accept(N)&&(!this.noDuplicate||!this.__isFileAlreadyAdded(N))){this.input.remove();
this.input.unbind("change",this.addProxy);
var M=new C(this,L);
this.list.append(M.getJQuery());
this.items.push(M);
this.input=this.cleanInput.clone();
this.inputContainer.append(this.input);
this.input.change(this.addProxy);
this.__updateButtons();
I.Event.fire(this.element,"onfileselect",N);
return true
}return false
},__removeItem:function(L){var M=D.inArray(L,this.items),N=D.inArray(L,this.submitedItems);
if(M!=-1){this.items.splice(M,1)
}if(N!=-1){this.submitedItems.splice(N,1)
}this.__updateButtons();
I.Event.fire(this.element,"onclear",[L.model])
},__removeAllItems:function(M){var N=[];
for(var L=0;
L<this.submitedItems.length;
L++){N.push(this.submitedItems[L].model)
}for(var L=0;
L<this.items.length;
L++){N.push(this.items[L].model)
}this.list.empty();
this.items.splice(0,this.items.length);
this.submitedItems.splice(0,this.submitedItems.length);
this.__updateButtons();
I.Event.fire(this.element,"onclear",N)
},__updateButtons:function(){if(!this.loadableItem&&this.list.children(".rf-fu-itm").size()){if(this.items.length){this.uploadButton.css("display","inline-block")
}else{this.uploadButton.hide()
}this.clearButton.css("display","inline-block")
}else{this.uploadButton.hide();
this.clearButton.hide()
}if(this.maxFilesQuantity&&this.__getTotalItemCount()>=this.maxFilesQuantity){this.addButton.hide()
}else{this.addButton.css("display","inline-block")
}},__startUpload:function(){if(!this.items.length){this.__finishUpload();
return 
}I.setGlobalStatusNameVariable(this.status);
this.loadableItem=this.items.shift();
this.__updateButtons();
this.loadableItem.startUploading()
},__accept:function(O){O=O.toUpperCase();
var L=!this.acceptedTypes;
for(var M=0;
!L&&M<this.acceptedTypes.length;
M++){var N=this.acceptedTypes[M];
if(N===""&&O.indexOf(".")<0){L=true
}else{L=O.indexOf(N,O.length-N.length)!==-1
}}if(!L){throw new B(O)
}return L
},__isFileAlreadyAdded:function(N){var L=false;
for(var M=0;
!L&&M<this.items.length;
M++){L=this.items[M].model.name==N
}L=L||(this.loadableItem&&this.loadableItem.model.name==N);
for(var M=0;
!L&&M<this.submitedItems.length;
M++){L=this.submitedItems[M].model.name==N
}return L
},__getTotalItemCount:function(){return this.__getItemCountByState(this.items,F.NEW)+this.__getItemCountByState(this.submitedItems,F.DONE)
},__getItemCountByState:function(L){var O={};
var N=0;
for(var M=1;
M<arguments.length;
M++){O[arguments[M]]=true
}for(var M=0;
M<L.length;
M++){if(O[L[M].model.state]){N++
}}return N
},__finishUpload:function(){this.loadableItem=null;
this.__updateButtons();
var L=[];
for(var M=0;
M<this.submitedItems.length;
M++){L.push(this.submitedItems[M].model)
}for(var M=0;
M<this.items.length;
M++){L.push(this.items[M].model)
}I.Event.fire(this.element,"onuploadcomplete",L)
}}
})());
var C=function(M,L){this.fileUpload=M;
this.model={name:L.name,state:F.NEW,file:L}
};
D.extend(C.prototype,{getJQuery:function(){this.element=D(G);
var L=this.element.children(".rf-fu-itm-lft:first");
this.label=L.children(".rf-fu-itm-lbl:first");
this.state=this.label.nextAll(".rf-fu-itm-st:first");
this.progressBar=L.find(".progress-bar");
this.progressBar.parent().hide();
this.progressLabel=this.progressBar.find("span");
this.link=L.next().children("a");
this.label.html(this.model.name);
this.link.html(this.fileUpload.deleteLabel);
this.link.click(D.proxy(this.removeOrStop,this));
return this.element
},removeOrStop:function(){this.element.remove();
this.fileUpload.__removeItem(this)
},startUploading:function(){this.state.css("display","block");
this.progressBar.parent().show();
this.progressLabel.html("0 %");
this.link.html("");
this.model.state=F.UPLOADING;
this.uid=Math.random();
var N=new FormData(),P=this.model.file.name,Q=this.fileUpload.form.find("input[name='javax.faces.ViewState']").val();
N.append(this.fileUpload.form[0].id,this.fileUpload.form[0].id);
N.append("javax.faces.ViewState",Q);
N.append(this.fileUpload.id,this.model.file);
var T=this.fileUpload.form.attr("action"),L=T.indexOf("?")==-1?"?":"&",S=encodeURIComponent(this.fileUpload.id),R=T+L+A+"="+this.uid+"&javax.faces.partial.ajax=true&javax.faces.source="+S+"&javax.faces.partial.execute="+S+"&org.richfaces.ajax.component="+S+"&javax.faces.ViewState="+encodeURIComponent(Q);
if(jsf.getClientWindow&&jsf.getClientWindow()){R+="&javax.faces.ClientWindow="+encodeURIComponent(jsf.getClientWindow())
}var O=function(V){if(V){var U="try {"+V+"} catch (e) {window.RichFaces.log.error('Error in method execution: ' + e.message)}";
return new Function("event",U)
}};
this.onerror=O(this.fileUpload.onerror);
this.xhr=new XMLHttpRequest();
this.xhr.open("POST",R,true);
this.xhr.setRequestHeader("Faces-Request","partial/ajax");
this.xhr.upload.onprogress=D.proxy(function(V){if(V.lengthComputable){var U=Math.floor((V.loaded/V.total)*100);
this.progressLabel.html(U+" %");
this.progressBar.attr("aria-valuenow",U);
this.progressBar.css("width",U+"%")
}},this);
this.xhr.upload.onerror=D.proxy(function(U){this.fileUpload.loadableItem=null;
this.finishUploading(F.SERVER_ERROR_UPLOAD)
},this);
this.xhr.onload=D.proxy(function(X){switch(X.target.status){case 413:responseStatus=F.SIZE_EXCEEDED;
break;
case 200:responseStatus=F.DONE;
break;
default:responseStatus=F.SERVER_ERROR_PROCESS
}var Y=function(a){return function(e){var b=D("partial-response extension#org\\.richfaces\\.extension",e.responseXML);
var d=b.children(a).text();
var c=O(d);
if(c){c.call(this,e)
}D("form").trigger("ajaxcomplete")
}
};
var V=I.createJSFEventsAdapter({complete:Y("complete"),error:Y("error")});
var Z={source:this.fileUpload.element[0],element:this.fileUpload.element[0],_mfInternal:{_mfSourceControlId:this.fileUpload.element.attr("id")},onevent:V,onerror:V};
var U=O(this.fileUpload.onbeforedomupdate);
if(U){var W={};
W.type="event";
W.status="complete";
W.source=this.fileUpload.element[0];
W.responseCode=this.xhr.status;
W.responseXML=this.xhr.responseXML;
W.responseText=this.xhr.responseText;
U.call(this.fileUpload,W)
}this.fileUpload.form.trigger("ajaxbeforedomupdate");
jsf.ajax.response(this.xhr,Z);
this.finishUploading(responseStatus);
this.fileUpload.__startUpload()
},this);
var M=O(this.fileUpload.onbegin);
if(M){M.call(this.fileUpload,{source:this.fileUpload.element[0],type:"event",status:"begin"})
}this.fileUpload.form.trigger("ajaxbegin");
this.xhr.send(N);
I.Event.fire(this.fileUpload.element,"onfilesubmit",this.model)
},finishUploading:function(L){if(L!=F.DONE&&this.onerror){this.onerror.call(this.fileUpload,{state:L,error:this.fileUpload[L+"Label"]})
}this.state.html(this.fileUpload[L+"Label"]);
this.progressBar.parent().hide();
this.link.html(this.fileUpload.clearLabel);
this.model.state=L;
this.fileUpload.submitedItems.push(this)
}})
}(RichFaces.jQuery,window.RichFaces));

==> richfaces-distribution-4.5.13.Final.zip: META-INF/resources/org.richfaces.staticResource/4.5.13.Final/Compressed/org.richfaces/fileupload.js <==
(function(D,I){I.ui=I.ui||{};
I.ui.FileUpload=function(O,M){this.id=O;
this.items=[];
this.submitedItems=[];
D.extend(this,M);
if(this.acceptedTypes){this.acceptedTypes=D.trim(this.acceptedTypes).toUpperCase().split(/\s*,\s*\.?/)
}if(this.maxFilesQuantity){this.maxFilesQuantity=parseInt(D.trim(this.maxFilesQuantity))
}this.element=D(this.attachToDom());
this.form=this.element.parents("form:first");
var N=this.element.children(".rf-fu-hdr:first");
var L=N.children(".rf-fu-btns-lft:first");
this.addButton=L.children(".rf-fu-btn-add:first");
this.uploadButton=this.addButton.next();
this.clearButton=L.next().children(".rf-fu-btn-clr:first");
this.inputContainer=this.addButton.find(".rf-fu-inp-cntr:first");
this.input=this.inputContainer.children("input");
this.list=N.next();
this.element.bind("dragenter",function(P){P.stopPropagation();
P.preventDefault()
});
this.element.bind("dragover",function(P){P.stopPropagation();
P.preventDefault()
});
this.element.bind("drop",D.proxy(this.__addItemsFromDrop,this));
this.hiddenContainer=this.list.next();
this.cleanInput=this.input.clone();
this.addProxy=D.proxy(this.__addItems,this);
this.input.change(this.addProxy);
this.addButton.mousedown(E).mouseup(H).mouseout(H);
this.uploadButton.click(D.proxy(this.__startUpload,this)).mousedown(E).mouseup(H).mouseout(H);
this.clearButton.click(D.proxy(this.__removeAllItems,this)).mousedown(E).mouseup(H).mouseout(H);
if(this.onfilesubmit){I.Event.bind(this.element,"onfilesubmit",new Function("event",this.onfilesubmit))
}if(this.ontyperejected){I.Event.bind(this.element,"ontyperejected",new Function("event",this.ontyperejected))
}if(this.onsizerejected){I.Event.bind(this.element,"onsizerejected",new Function("event",this.onsizerejected))
}if(this.onuploadcomplete){I.Event.bind(this.element,"onuploadcomplete",new Function("event",this.onuploadcomplete))
}if(this.onclear){I.Event.bind(this.element,"onclear",new Function("event",this.onclear))
}if(this.onfileselect){I.Event.bind(this.element,"onfileselect",new Function("event",this.onfileselect))
}};
var A="rf_fu_uid";
var J="rf_fu_uid_alt";
var K="C:\\fakepath\\";
var G='<div class="rf-fu-itm"><span class="rf-fu-itm-lft"><span class="rf-fu-itm-lbl"/><span class="rf-fu-itm-st" /></span><span class="rf-fu-itm-rgh"><a href="javascript:void(0)" class="rf-fu-itm-lnk"/></span></div>';
var F={NEW:"new",UPLOADING:"uploading",DONE:"done",SIZE_EXCEEDED:"sizeExceeded",STOPPED:"stopped",SERVER_ERROR_PROCESS:"serverErrorProc",SERVER_ERROR_UPLOAD:"serverErrorUp"};
var E=function(L){D(this).children(":first").css("background-position","3px 3px").css("padding","4px 4px 2px 22px")
};
var H=function(L){D(this).children(":first").css("background-position","2px 2px").css("padding","3px 5px 3px 21px")
};
I.BaseComponent.extend(I.ui.FileUpload);
function B(L){this.name="TypeRejectedException";
this.message="The type of file "+L+" is not accepted";
this.fileName=L
}D.extend(I.ui.FileUpload.prototype,(function(){return{name:"FileUpload",doneLabel:"Done",sizeExceededLabel:"File size is exceeded",stoppedLabel:"",serverErrorProcLabel:"Server error: error in processing",serverErrorUpLabel:"Server error: upload failed",clearLabel:"Clear",deleteLabel:"Delete",__addFiles:function(N){var M={acceptedFileNames:[],rejectedFileNames:[]};
if(N){for(var L=0;
L<N.length;
L++){this.__tryAddItem(M,N[L]);
if(this.maxFilesQuantity&&this.__getTotalItemCount()>=this.maxFilesQuantity){this.addButton.hide();
break
}}}else{var O=this.input.val();
this.__tryAddItem(M,O)
}if(M.rejectedFileNames.length>0){I.Event.fire(this.element,"ontyperejected",M.rejectedFileNames.join(","))
}if(this.immediateUpload){this.__startUpload()
}},__addItems:function(){this.__addFiles(this.input.prop("files"))
},__addItemsFromDrop:function(L){L.stopPropagation();
L.preventDefault();
if(this.maxFilesQuantity&&this.__getTotalItemCount()>=this.maxFilesQuantity){return 
}this.__addFiles(L.originalEvent.dataTransfer.files)
},__tryAddItem:function(M,L){if(this.maxFileSize&&L.size>this.maxFileSize){I.Event.fire(this.element,"onsizerejected",L);
return 
}try{if(this.__addItem(L)){M.acceptedFileNames.push(L.name)
}}catch(N){if(N instanceof B){M.rejectedFileNames.push(L.name)
}else{throw N
}}},__addItem:function(L){var N=L.name;
if(!navigator.platform.indexOf("Win")){N=N.match(/[^\\]*$/)[0]
}else{if(!N.indexOf(K)){N=N.substr(K.length)
}else{N=N.match(/[^\/]*$/)[0]
}}if(this.__accept(N)&&(!this.noDuplicate||!this.__isFileAlreadyAdded(N))){this.input.remove();
this.input.unbind("change",this.addProxy);
var M=new C(this,L);
this.list.append(M.getJQuery());
this.items.push(M);
this.input=this.cleanInput.clone();
this.inputContainer.append(this.input);
this.input.change(this.addProxy);
this.__updateButtons();
I.Event.fire(this.element,"onfileselect",N);
return true
}return false
},__removeItem:function(L){var M=D.inArray(L,this.items),N=D.inArray(L,this.submitedItems);
if(M!=-1){this.items.splice(M,1)
}if(N!=-1){this.submitedItems.splice(N,1)
}this.__updateButtons();
I.Event.fire(this.element,"onclear",[L.model])
},__removeAllItems:function(M){var N=[];
for(var L=0;
L<this.submitedItems.length;
L++){N.push(this.submitedItems[L].model)
}for(var L=0;
L<this.items.length;
L++){N.push(this.items[L].model)
}this.list.empty();
this.items.splice(0,this.items.length);
this.submitedItems.splice(0,this.submitedItems.length);
this.__updateButtons();
I.Event.fire(this.element,"onclear",N)
},__updateButtons:function(){if(!this.loadableItem&&this.list.children(".rf-fu-itm").size()){if(this.items.length){this.uploadButton.css("display","inline-block")
}else{this.uploadButton.hide()
}this.clearButton.css("display","inline-block")
}else{this.uploadButton.hide();
this.clearButton.hide()
}if(this.maxFilesQuantity&&this.__getTotalItemCount()>=this.maxFilesQuantity){this.addButton.hide()
}else{this.addButton.css("display","inline-block")
}},__startUpload:function(){if(!this.items.length){this.__finishUpload();
return 
}I.setGlobalStatusNameVariable(this.status);
this.loadableItem=this.items.shift();
this.__updateButtons();
this.loadableItem.startUploading()
},__accept:function(O){O=O.toUpperCase();
var L=!this.acceptedTypes;
for(var M=0;
!L&&M<this.acceptedTypes.length;
M++){var N=this.acceptedTypes[M];
if(N===""&&O.indexOf(".")<0){L=true
}else{L=O.indexOf(N,O.length-N.length)!==-1
}}if(!L){throw new B(O)
}return L
},__isFileAlreadyAdded:function(N){var L=false;
for(var M=0;
!L&&M<this.items.length;
M++){L=this.items[M].model.name==N
}L=L||(this.loadableItem&&this.loadableItem.model.name==N);
for(var M=0;
!L&&M<this.submitedItems.length;
M++){L=this.submitedItems[M].model.name==N
}return L
},__getTotalItemCount:function(){return this.__getItemCountByState(this.items,F.NEW)+this.__getItemCountByState(this.submitedItems,F.DONE)
},__getItemCountByState:function(L){var O={};
var N=0;
for(var M=1;
M<arguments.length;
M++){O[arguments[M]]=true
}for(var M=0;
M<L.length;
M++){if(O[L[M].model.state]){N++
}}return N
},__finishUpload:function(){this.loadableItem=null;
this.__updateButtons();
var L=[];
for(var M=0;
M<this.submitedItems.length;
M++){L.push(this.submitedItems[M].model)
}for(var M=0;
M<this.items.length;
M++){L.push(this.items[M].model)
}I.Event.fire(this.element,"onuploadcomplete",L)
}}
})());
var C=function(M,L){this.fileUpload=M;
this.model={name:L.name,state:F.NEW,file:L}
};
D.extend(C.prototype,{__createProgressBar:function(M,O){var L=O.find(".rf-pb");
if(L.length){return{pb:RichFaces.component(L),prepare:function(){M.find(".rf-fu-itm-lft").append(L.detach())
},setValue:function(Q){var P=parseFloat(this.pb.maxValue),S=parseFloat(this.pb.minValue),R=Q*(P-S)/100+S;
this.pb.setValue(R)
},cleanUp:function(){O.append(L.detach())
},show:function(){L.show()
},hide:function(){L.hide()
}}
}var N='<div class="progress progress-striped active"><div class="progress-bar" role="progressbar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100" style="width: 0%"><span></span></div></div>';
return{prepare:function(){M.find(".rf-fu-itm-lft").append(D(N));
this.element=M.find(".progress-bar");
this.label=this.element.find("span")
},setValue:function(P){this.label.html(P+" %");
this.element.attr("aria-valuenow",P);
this.element.css("width",P+"%")
},cleanUp:function(){},show:function(){this.element.parent().show()
},hide:function(){this.element.parent().hide()
}}
},getJQuery:function(){this.element=D(G);
var L=this.element.children(".rf-fu-itm-lft:first");
this.label=L.children(".rf-fu-itm-lbl:first");
this.state=this.label.nextAll(".rf-fu-itm-st:first");
this.link=L.next().children("a");
this.label.html(this.model.name);
this.link.html(this.fileUpload.deleteLabel);
this.link.click(D.proxy(this.removeOrStop,this));
return this.element
},removeOrStop:function(){this.element.remove();
this.fileUpload.__removeItem(this)
},startUploading:function(){this.progressBarFacet=this.__createProgressBar(this.element,this.fileUpload.hiddenContainer);
this.progressBarFacet.prepare();
this.progressBarFacet.hide();
this.state.css("display","block");
this.progressBarFacet.setValue(0);
this.progressBarFacet.show();
this.link.html("");
this.model.state=F.UPLOADING;
this.uid=Math.random();
var N=new FormData(),P=this.model.file.name,Q=this.fileUpload.form.find("input[name='javax.faces.ViewState']").val();
N.append(this.fileUpload.form[0].id,this.fileUpload.form[0].id);
N.append("javax.faces.ViewState",Q);
N.append(this.fileUpload.id,this.model.file);
var T=this.fileUpload.form.attr("action"),L=T.indexOf("?")==-1?"?":"&",S=encodeURIComponent(this.fileUpload.id),R=T+L+A+"="+this.uid+"&javax.faces.partial.ajax=true&javax.faces.source="+S+"&javax.faces.partial.execute="+S+"&org.richfaces.ajax.component="+S+"&javax.faces.ViewState="+encodeURIComponent(Q);
if(jsf.getClientWindow&&jsf.getClientWindow()){R+="&javax.faces.ClientWindow="+encodeURIComponent(jsf.getClientWindow())
}var O=function(V){if(V){var U="try {"+V+"} catch (e) {window.RichFaces.log.error('Error in method execution: ' + e.message)}";
return new Function("event",U)
}};
this.onerror=O(this.fileUpload.onerror);
this.xhr=new XMLHttpRequest();
this.xhr.open("POST",R,true);
this.xhr.setRequestHeader("Faces-Request","partial/ajax");
this.xhr.upload.onprogress=D.proxy(function(V){if(V.lengthComputable){var U=Math.floor((V.loaded/V.total)*100);
this.progressBarFacet.setValue(U)
}},this);
this.xhr.upload.onerror=D.proxy(function(U){this.fileUpload.loadableItem=null;
this.finishUploading(F.SERVER_ERROR_UPLOAD)
},this);
this.xhr.onload=D.proxy(function(X){switch(X.target.status){case 413:responseStatus=F.SIZE_EXCEEDED;
break;
case 200:responseStatus=F.DONE;
break;
default:responseStatus=F.SERVER_ERROR_PROCESS
}var Y=function(a){return function(e){var b=D("partial-response extension#org\\.richfaces\\.extension",e.responseXML);
var d=b.children(a).text();
var c=O(d);
if(c){c.call(this,e)
}D("form").trigger("ajaxcomplete")
}
};
var V=I.createJSFEventsAdapter({complete:Y("complete"),error:Y("error")});
var Z={source:this.fileUpload.element[0],sourceid:this.fileUpload.element[0],element:this.fileUpload.element[0],_mfInternal:{_mfSourceControlId:this.fileUpload.element.attr("id")},onevent:V,onerror:V};
var U=O(this.fileUpload.onbeforedomupdate);
if(U){var W={};
W.type="event";
W.status="complete";
W.source=this.fileUpload.element[0];
W.responseCode=this.xhr.status;
W.responseXML=this.xhr.responseXML;
W.responseText=this.xhr.responseText;
U.call(this.fileUpload,W)
}this.fileUpload.form.trigger("ajaxbeforedomupdate");
jsf.ajax.response(this.xhr,Z);
this.finishUploading(responseStatus);
this.fileUpload.__startUpload()
},this);
var M=O(this.fileUpload.onbegin);
if(M){M.call(this.fileUpload,{source:this.fileUpload.element[0],type:"event",status:"begin"})
}this.fileUpload.form.trigger("ajaxbegin");
this.xhr.send(N);
I.Event.fire(this.fileUpload.element,"onfilesubmit",this.model)
},finishUploading:function(L){if(L!=F.DONE&&this.onerror){this.onerror.call(this.fileUpload,{state:L,error:this.fileUpload[L+"Label"]})
}this.state.html(this.fileUpload[L+"Label"]);
this.progressBarFacet.hide();
this.progressBarFacet.cleanUp();
this.link.html(this.fileUpload.clearLabel);
this.model.state=L;
this.fileUpload.submitedItems.push(this)
}})
}(RichFaces.jQuery,window.RichFaces));
